@@ -36,11 +36,14 @@ class FSMViewSetMixinMetaclass(type):
         # The class needs the field FSM_MODELFIELDS to know which transitions it needs to add
         if hasattr(_class, "get_model"):
             model = _class.get_model()
+
             if model:
+                setattr(_class, "FSM_BUTTONS", getattr(_class, "FSM_BUTTONS", set()))
                 # The model potentially has multiple FSMFields, which needs to be iterated over
                 for field in filter(lambda f: isinstance(f, FSMField), model._meta.fields):
                     # Get all transitions, by calling the partialmethod defined by django-fsm
                     transitions = getattr(model, f"get_all_{field.name}_transitions")(model())
+
                     # Since the method above can potentially return a transition multiple times
                     # i.e. when a transitions has multiple sources, we need to filter out those transitions
                     _discovered_transitions = list()
@@ -53,20 +56,7 @@ class FSMViewSetMixinMetaclass(type):
 
                         # Get the Transition Button and add it to the front of the instance buttons
                         button = transition.custom.get("_transition_button")
-
-                        instance_btns = [button] + list(
-                            filter(lambda x: button.key != x.key, getattr(_class, "CUSTOM_INSTANCE_BUTTONS", []),)
-                        )
-                        list_btns = [button] + list(
-                            filter(lambda x: button.key != x.key, getattr(_class, "CUSTOM_LIST_INSTANCE_BUTTONS", []),)
-                        )
-
-                        setattr(
-                            _class, "CUSTOM_INSTANCE_BUTTONS", instance_btns,
-                        )
-                        setattr(
-                            _class, "CUSTOM_LIST_INSTANCE_BUTTONS", list_btns,
-                        )
+                        _class.FSM_BUTTONS.add(button)
 
                         # Create a method that calls fsm_route with the request and the action name
                         method = get_method(transition)
@@ -150,7 +140,13 @@ class FSMSerializerMetaclass(SerializerMetaclass):
                             # NOTE: What happens if the reverse parameter is not called pk?
                             # NOTE: Is that even possible?
 
-                            kwargs = self.context["view"].kwargs
+                            # If the view is not in the context, we just create an empty keyword dict.
+                            # FIXME: This should actually never happen
+                            try:
+                                kwargs = self.context["view"].kwargs
+                            except KeyError:
+                                kwargs = {}
+                            
                             kwargs.update({"pk": instance.id})
 
                             endpoint = reverse(
