@@ -11,13 +11,14 @@ from bridger.pagination import CursorPagination
 from .generics import GenericAPIView
 from .mixins import (
     CreateModelMixin,
-    DestroyModelMixin,
     DestroyMultipleModelMixin,
     FilterMixin,
     ListModelMixin,
     ModelMixin,
     RetrieveModelMixin,
     UpdateModelMixin,
+    DestroyModelMixin,
+    DocumentationMixin,
 )
 
 
@@ -25,24 +26,25 @@ class GenericViewSet(ViewSetMixin, GenericAPIView):
     pass
 
 
-class ViewSet(MetadataMixin, ViewSet):
+class ViewSet(MetadataMixin, ModelMixin, DocumentationMixin, ViewSet):
     def get_serializer(self):
-        return self.serializer_class()
+        if hasattr(self, "serializer_class"):
+            return self.serializer_class()
+        return None
 
     def get_serializer_class(self):
         return getattr(self, "serializer_class", None)
 
 
 class ReadOnlyModelViewSet(
-    MetadataMixin, ModelMixin, RetrieveModelMixin, ListModelMixin, FilterMixin, GenericViewSet,
+    DocumentationMixin, MetadataMixin, ModelMixin, RetrieveModelMixin, ListModelMixin, FilterMixin, GenericViewSet,
 ):
     pagination_class = CursorPagination
     READ_ONLY = True
-    CREATE_BUTTONS = []
-    BUTTONS = [Button.REFRESH.value]
 
 
 class ModelViewSet(
+    DocumentationMixin,
     FSMViewSetMixin,
     MetadataMixin,
     ModelMixin,
